'use client'

import { useState, useEffect } from 'react'
import { FiClock, FiCheckCircle, FiAlertCircle, FiPrinter } from 'react-icons/fi'
import DashboardLayout from '@/components/layout/DashboardLayout'
import { kitchenService } from '@/services/api'
import { useUser } from '@/contexts/UserContext'

interface KitchenOrder {
  id: number
  table_name: string
  product_name: string
  product_image: string
  quantity: number
  created_at: string
  status: string
  description?: string
  completed?: boolean
}

// Tarih formatlama yardımcı fonksiyonu
const formatTarihSaat = (tarihStr: string | null | undefined) => {
  try {
    if (!tarihStr) return '-'
    
    // Tarih formatını kontrol et
    const tarihMatch = tarihStr.match(/(\d{4})-(\d{2})-(\d{2})\s+(\d{2}):(\d{2})/)
    if (!tarihMatch) return tarihStr

    const [_, yil, ay, gun, saat, dakika] = tarihMatch
    return `${gun}.${ay}.${yil} ${saat}:${dakika}`

  } catch (error) {
    console.error('Tarih formatlama hatası:', error)
    return tarihStr || '-'
  }
}

export default function KitchenPage() {
  const { user } = useUser()
  const [orders, setOrders] = useState<KitchenOrder[]>([])
  const [loading, setLoading] = useState(true)

  const fetchKitchenOrders = async () => {
    try {
      const response = await kitchenService.index(user?.token || '')
      setOrders(response.data.kitchen_orders)
      console.log(response.data.kitchen_orders)
      setLoading(false)
    } catch (error) {
      console.error('Mutfak siparişleri yüklenirken hata:', error)
      setLoading(false)
    }
  }

  const handleCompleteOrder = async (orderId: number) => {
    try {
      await kitchenService.complete(orderId, user?.token || '')
      setOrders(prevOrders => 
        prevOrders.filter(order => order.id !== orderId)
      )
    } catch (error) {
      console.error('Sipariş tamamlanırken hata:', error)
    }
  }

  const handlePrintOrder = async (order: KitchenOrder) => {
    try {
      const printWindow = window.open('', '_blank')
      const orderTime = formatTarihSaat(order.created_at)
      
      const orderText = `
        ===== MUTFAK SİPARİŞİ =====
        Masa: ${order.table_name}
        Tarih: ${orderTime}
        
        Ürün: ${order.product_name}
        Adet: ${order.quantity}
        
        ${order.description ? `Not: ${order.description}` : ''}
        =======================
      `

      if (printWindow) {
        printWindow.document.write(`
          <html>
            <head>
              <title>Mutfak Siparişi</title>
              <style>
                @media print {
                  body { 
                    font-family: monospace;
                    white-space: pre;
                    margin: 0;
                    padding: 20px;
                    font-size: 14px;
                    line-height: 1.5;
                  }
                  @page {
                    size: 80mm auto;
                    margin: 0;
                  }
                }
              </style>
            </head>
            <body>
              <pre>${orderText}</pre>
              <script>
                window.onload = function() {
                  window.print();
                  setTimeout(function() { window.close(); }, 500);
                }
              </script>
            </body>
          </html>
        `)
        printWindow.document.close()
      }
    } catch (error) {
      console.error('Yazdırma hatası:', error)
    }
  }

  useEffect(() => {
    if (user?.token) {
      fetchKitchenOrders()
      const interval = setInterval(fetchKitchenOrders, 30000)
      return () => clearInterval(interval)
    }
  }, [user?.token])

  return (
    <DashboardLayout>
      <div className="container mx-auto px-4 py-6">
        {/* Başlık */}
        <div className="mb-8">
          <h1 className="text-2xl font-bold text-slate-800 dark:text-white">
            Mutfak Siparişleri
          </h1>
          <p className="text-slate-500 dark:text-slate-400 mt-2">
            Hazırlanması gereken siparişlerin listesi
          </p>
        </div>

        <div className="grid grid-cols-1 md:grid-cols-2 lg:grid-cols-3 gap-6">
          {orders.map((order) => (
            <div
              key={order.id}
              className="bg-white dark:bg-slate-800 rounded-2xl shadow-sm 
                       border border-slate-200 dark:border-slate-700
                       hover:shadow-lg transition-all"
            >
              <div className="p-6 space-y-4">
                {/* Üst Bilgi - Masa ve Saat */}
                <div className="flex items-center justify-between">
                  <div className="flex items-center gap-3">
                    <div className="p-2 bg-fuchsia-50 dark:bg-fuchsia-900/50 rounded-xl">
                      <FiClock className="w-5 h-5 text-fuchsia-500" />
                    </div>
                    <div>
                      <h3 className="text-lg font-semibold text-slate-800 dark:text-white">
                        {order.table_name}
                      </h3>
                      <p className="text-sm text-slate-500 dark:text-slate-400">
                        {formatTarihSaat(order.created_at)}
                      </p>
                    </div>
                  </div>
                  <span className={`px-3 py-1 text-xs font-medium rounded-full 
                                ${order.status === 'pending' 
                                  ? 'bg-green-100 dark:bg-green-900/50 text-green-600 dark:text-green-400'  
                                  : 'bg-amber-100 dark:bg-amber-900/50 text-amber-600 dark:text-amber-400'
                                }`}>
                    {order.status === 'pending' ? 'Bekliyor' : 'Hazırlandı'}
                  </span>
                </div>

                {/* Ürün Detayları */}
                <div className="flex items-start gap-4">
                  <img
                    src={`${process.env.NEXT_PUBLIC_API_URL_STORAGE}/${order.product_image}`}
                    alt={order.product_name}
                    className="w-20 h-20 object-cover rounded-xl"
                  />
                  <div className="flex-1">
                    <h4 className="text-lg font-medium text-slate-800 dark:text-white">
                      {order.product_name}
                    </h4>
                    <p className="text-sm text-slate-500 dark:text-slate-400 mt-1">
                      {order.quantity} adet
                    </p>
                    {order.description && (
                      <p className="text-sm text-slate-600 dark:text-slate-300 mt-2 
                                  p-2 bg-slate-50 dark:bg-slate-700/50 rounded-lg">
                        {order.description}
                      </p>
                    )}
                  </div>
                </div>

                {/* Hazırlandı Butonu */}
                <div className="pt-4 border-t border-slate-100 dark:border-slate-700 space-y-2">
                  <button
                    onClick={() => handlePrintOrder(order)}
                    className="w-full px-4 py-2 text-sm font-medium text-slate-700 dark:text-slate-200
                             bg-slate-100 dark:bg-slate-700
                             rounded-xl hover:opacity-90 transition-all
                             flex items-center justify-center gap-2"
                  >
                    <FiPrinter className="w-4 h-4" />
                    Yazdır
                  </button>

                  <button
                    onClick={() => handleCompleteOrder(order.id)}
                    className="w-full px-4 py-2 text-sm font-medium text-white
                             bg-gradient-to-r from-green-500 to-emerald-600
                             rounded-xl hover:opacity-90 transition-all
                             flex items-center justify-center gap-2"
                  >
                    <FiCheckCircle className="w-4 h-4" />
                    Hazırlandı Olarak İşaretle
                  </button>
                </div>
              </div>
            </div>
          ))}
        </div>

        {/* Yükleniyor */}
        {loading && (
          <div className="flex justify-center items-center min-h-[400px]">
            <div className="animate-spin rounded-full h-12 w-12 border-b-2 border-fuchsia-500"></div>
          </div>
        )}

        {/* Veri Yoksa */}
        {!loading && orders.length === 0 && (
          <div className="flex flex-col items-center justify-center min-h-[400px] 
                       bg-white dark:bg-slate-800 rounded-2xl border 
                       border-slate-200 dark:border-slate-700 p-8">
            <FiCheckCircle className="w-16 h-16 text-green-500 mb-4" />
            <h2 className="text-xl font-semibold text-slate-800 dark:text-white mb-2">
              Tüm Siparişler Hazır!
            </h2>
            <p className="text-slate-500 dark:text-slate-400 text-center">
              Şu anda bekleyen sipariş bulunmuyor.
            </p>
          </div>
        )}
      </div>
    </DashboardLayout>
  )
} 